@@ -42,9 +42,14 @@ class DecimalClock(clock.Clock):
                 h = h % 12
                 abrv = "PM"
 
-        text = str(h).zfill(2) + ":" + str(self.time.minute).zfill(2)
+        if self.pad_zeros :
+            fill_char = '0'
+        else :
+            fill_char = ' '
+
+        text = str(h).rjust(2, fill_char) + ":" + str(self.time.minute).rjust(2, fill_char)
         if self.show_seconds :
-            text = text + ":" + str(self.time.second).zfill(2)
+            text = text + ":" + str(self.time.second).rjust(2, fill_char)
         
         self.context.text_path(text)
         if self.fill :
